#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.2
visibility:           public
id:                   constraints-extras-0.4.0.2-58yeRXzNL6cA7G0GmDSrWw
key:                  constraints-extras-0.4.0.2-58yeRXzNL6cA7G0GmDSrWw
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  4bd1c6a4cf1213cc4485d46035bace67
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/constraints-extras-0.4.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.2-58yeRXzNL6cA7G0GmDSrWw
depends:
    base-4.18.2.1 constraints-0.14.3-EtnHoi90KKFCBB7gkT021I
    template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

